@@ -6,10 +6,11 @@ Type annotations for shield service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_shield import ShieldClient
+    from boto3.session import Session
+    from mypy_boto3_shield.client import ShieldClient
 
-    client: ShieldClient = boto3.client("shield")
+    session = Session()
+    client: ShieldClient = session.client("shield")
     ```
 """
 import sys
@@ -81,7 +82,7 @@ class Exceptions:
 
 class ShieldClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html)
     """
 
@@ -91,6 +92,9 @@ class ShieldClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         ShieldClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#exceptions)
         """
 
     def associate_drt_log_bucket(self, *, LogBucket: str) -> Dict[str, Any]:
@@ -99,7 +103,7 @@ class ShieldClient(BaseClient):
         bucket containing log data such as Application Load Balancer access logs,
         CloudFront logs, or logs from third party sources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.associate_drt_log_bucket)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.associate_drt_log_bucket)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_drt_log_bucket)
         """
 
@@ -109,7 +113,7 @@ class ShieldClient(BaseClient):
         your Amazon Web Services account to assist with DDoS attack mitigation during
         potential attacks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.associate_drt_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.associate_drt_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_drt_role)
         """
 
@@ -117,7 +121,7 @@ class ShieldClient(BaseClient):
         """
         Adds health-based detection to the Shield Advanced protection for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.associate_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.associate_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_health_check)
         """
 
@@ -128,7 +132,7 @@ class ShieldClient(BaseClient):
         Initializes proactive engagement and sets the list of contacts for the Shield
         Response Team (SRT) to use.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.associate_proactive_engagement_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.associate_proactive_engagement_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#associate_proactive_engagement_details)
         """
 
@@ -136,7 +140,7 @@ class ShieldClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#can_paginate)
         """
 
@@ -146,7 +150,7 @@ class ShieldClient(BaseClient):
         """
         Enables Shield Advanced for a specific Amazon Web Services resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.create_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.create_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_protection)
         """
 
@@ -164,7 +168,7 @@ class ShieldClient(BaseClient):
         Creates a grouping of protected resources so they can be handled as a
         collective.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.create_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.create_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_protection_group)
         """
 
@@ -172,7 +176,7 @@ class ShieldClient(BaseClient):
         """
         Activates Shield Advanced for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.create_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.create_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#create_subscription)
         """
 
@@ -180,7 +184,7 @@ class ShieldClient(BaseClient):
         """
         Deletes an Shield Advanced  Protection .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.delete_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.delete_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_protection)
         """
 
@@ -188,7 +192,7 @@ class ShieldClient(BaseClient):
         """
         Removes the specified protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.delete_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.delete_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_protection_group)
         """
 
@@ -196,7 +200,7 @@ class ShieldClient(BaseClient):
         """
         Removes Shield Advanced from an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.delete_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.delete_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#delete_subscription)
         """
 
@@ -204,7 +208,7 @@ class ShieldClient(BaseClient):
         """
         Describes the details of a DDoS attack.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.describe_attack)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.describe_attack)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_attack)
         """
 
@@ -214,7 +218,7 @@ class ShieldClient(BaseClient):
         the last year for all resources that belong to your account, regardless of
         whether you've defined Shield protections for them.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.describe_attack_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.describe_attack_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_attack_statistics)
         """
 
@@ -224,7 +228,7 @@ class ShieldClient(BaseClient):
         Response Team (SRT) to access your Amazon Web Services account while assisting
         with attack mitigation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.describe_drt_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.describe_drt_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_drt_access)
         """
 
@@ -236,7 +240,7 @@ class ShieldClient(BaseClient):
         can use to contact you if you have proactive engagement enabled, for escalations
         to the SRT and to initiate proactive customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.describe_emergency_contact_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.describe_emergency_contact_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_emergency_contact_settings)
         """
 
@@ -246,7 +250,7 @@ class ShieldClient(BaseClient):
         """
         Lists the details of a  Protection object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.describe_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.describe_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_protection)
         """
 
@@ -256,7 +260,7 @@ class ShieldClient(BaseClient):
         """
         Returns the specification for the specified protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.describe_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.describe_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_protection_group)
         """
 
@@ -264,7 +268,7 @@ class ShieldClient(BaseClient):
         """
         Provides details about the Shield Advanced subscription for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.describe_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.describe_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#describe_subscription)
         """
 
@@ -273,7 +277,7 @@ class ShieldClient(BaseClient):
         Disable the Shield Advanced automatic application layer DDoS mitigation feature
         for the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.disable_application_layer_automatic_response)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.disable_application_layer_automatic_response)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disable_application_layer_automatic_response)
         """
 
@@ -282,7 +286,7 @@ class ShieldClient(BaseClient):
         Removes authorization from the Shield Response Team (SRT) to notify contacts
         about escalations to the SRT and to initiate proactive customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.disable_proactive_engagement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.disable_proactive_engagement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disable_proactive_engagement)
         """
 
@@ -291,7 +295,7 @@ class ShieldClient(BaseClient):
         Removes the Shield Response Team's (SRT) access to the specified Amazon S3
         bucket containing the logs that you shared previously.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.disassociate_drt_log_bucket)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.disassociate_drt_log_bucket)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_drt_log_bucket)
         """
 
@@ -300,7 +304,7 @@ class ShieldClient(BaseClient):
         Removes the Shield Response Team's (SRT) access to your Amazon Web Services
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.disassociate_drt_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.disassociate_drt_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_drt_role)
         """
 
@@ -311,7 +315,7 @@ class ShieldClient(BaseClient):
         Removes health-based detection from the Shield Advanced protection for a
         resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.disassociate_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.disassociate_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#disassociate_health_check)
         """
 
@@ -322,7 +326,7 @@ class ShieldClient(BaseClient):
         Enable the Shield Advanced automatic application layer DDoS mitigation for the
         resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.enable_application_layer_automatic_response)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.enable_application_layer_automatic_response)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#enable_application_layer_automatic_response)
         """
 
@@ -332,7 +336,7 @@ class ShieldClient(BaseClient):
         contacts about escalations to the SRT and to initiate proactive customer
         support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.enable_proactive_engagement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.enable_proactive_engagement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#enable_proactive_engagement)
         """
 
@@ -346,7 +350,7 @@ class ShieldClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#generate_presigned_url)
         """
 
@@ -354,7 +358,7 @@ class ShieldClient(BaseClient):
         """
         Returns the `SubscriptionState` , either `Active` or `Inactive` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.get_subscription_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.get_subscription_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#get_subscription_state)
         """
 
@@ -371,7 +375,7 @@ class ShieldClient(BaseClient):
         Returns all ongoing DDoS attacks or all DDoS attacks during a specified time
         period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.list_attacks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.list_attacks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_attacks)
         """
 
@@ -381,7 +385,7 @@ class ShieldClient(BaseClient):
         """
         Retrieves the  ProtectionGroup objects for the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.list_protection_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.list_protection_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_protection_groups)
         """
 
@@ -391,7 +395,7 @@ class ShieldClient(BaseClient):
         """
         Lists all  Protection objects for the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.list_protections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.list_protections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_protections)
         """
 
@@ -401,7 +405,7 @@ class ShieldClient(BaseClient):
         """
         Retrieves the resources that are included in the protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.list_resources_in_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.list_resources_in_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_resources_in_protection_group)
         """
 
@@ -410,7 +414,7 @@ class ShieldClient(BaseClient):
         Gets information about Amazon Web Services tags for a specified Amazon Resource
         Name (ARN) in Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#list_tags_for_resource)
         """
 
@@ -418,7 +422,7 @@ class ShieldClient(BaseClient):
         """
         Adds or updates tags for a resource in Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#tag_resource)
         """
 
@@ -426,7 +430,7 @@ class ShieldClient(BaseClient):
         """
         Removes tags from a resource in Shield.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#untag_resource)
         """
 
@@ -437,7 +441,7 @@ class ShieldClient(BaseClient):
         Updates an existing Shield Advanced automatic application layer DDoS mitigation
         configuration for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.update_application_layer_automatic_response)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.update_application_layer_automatic_response)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_application_layer_automatic_response)
         """
 
@@ -450,7 +454,7 @@ class ShieldClient(BaseClient):
         engagement enabled, for escalations to the SRT and to initiate proactive
         customer support.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.update_emergency_contact_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.update_emergency_contact_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_emergency_contact_settings)
         """
 
@@ -466,7 +470,7 @@ class ShieldClient(BaseClient):
         """
         Updates an existing protection group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.update_protection_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.update_protection_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_protection_group)
         """
 
@@ -474,15 +478,15 @@ class ShieldClient(BaseClient):
         """
         Updates the details of an existing subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Client.update_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.update_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#update_subscription)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_attacks"]) -> ListAttacksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Paginator.ListAttacks)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listattackspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#get_paginator)
         """
 
     @overload
@@ -490,6 +494,6 @@ class ShieldClient(BaseClient):
         self, operation_name: Literal["list_protections"]
     ) -> ListProtectionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/shield.html#Shield.Paginator.ListProtections)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listprotectionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#Shield.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/client.html#get_paginator)
         """
